searchData={"items":[{"type":"module","title":"Livebook","doc":"This module provides a public Elixir API for integrating with Livebook.","ref":"Livebook.html"},{"type":"module","title":"Configuration - Livebook","doc":"See `config_runtime/0` for bootstrapping the default runtime\nconfiguration. There are several public configuration entries that\nyou can customize.","ref":"Livebook.html#module-configuration"},{"type":"module","title":"Custom plugs - Livebook","doc":"You can list a number of plugs to call directly before the Livebook\nrouter\n\n    config :livebook, :plugs, [{CustomPlug, []}]","ref":"Livebook.html#module-custom-plugs"},{"type":"module","title":"Embedded runtime dependencies - Livebook","doc":"In case you use the Embedded runtime and support installing\ndependencies with `Mix.install/2`, you can make those discoverable\nin the package search, by configuring a loader function:\n\n    config :livebook, Livebook.Runtime.Embedded,\n      load_packages: {Loader, :packages, []}\n\nThe function should return a list of entries like this:\n\n    [\n      %{\n        dependency: %{dep: {:kino, \"~> 0.6.1\"}, config: []},\n        description: \"Interactive widgets for Livebook\",\n        name: \"kino\",\n        url: \"https://hex.pm/packages/kino\",\n        version: \"0.6.1\"\n      }\n    ]","ref":"Livebook.html#module-embedded-runtime-dependencies"},{"type":"module","title":"Custom learn notebooks - Livebook","doc":"**Note that this is compile time configuration.**\n\nA list of additional notebooks to include in the Learn section.\n\nNote that the notebooks are loaded and embedded in a compiled module,\nso the paths are accessed at compile time only.\n\n    config :livebook, :learn_notebooks, [\n      %{\n        # Required notebook path\n        path: \"/path/to/notebook.livemd\",\n        # Optional notebook identifier for URLs, as in /learn/notebooks/{slug}\n        # By default the slug is inferred from file name, so there is no need to set it\n        slug: \"my-notebook\"\n        # Optional list of images\n        image_paths: [\n          # This image can be sourced as images/myimage.jpg in the notebook\n          \"/path/to/myimage.jpg\"\n        ],\n        # Optional details for the notebook card. If omitted, the notebook\n        # is hidden in the UI, but still accessible under /learn/notebooks/{slug}\n        details: %{\n          cover_path: \"/path/to/logo.png\",\n          description: \"My custom notebook that showcases some amazing stuff.\"\n        }\n      },\n      %{\n        path: \"/path/to/other_notebook.livemd\"\n      }\n    ]","ref":"Livebook.html#module-custom-learn-notebooks"},{"type":"function","title":"Livebook.config_runtime/0","doc":"Executes Livebook's `config/runtime.exs`.\n\nIf you use Livebook as a dependency, you can add the following\nto your `config/runtime.exs` to trigger Livebook's `config/runtime.exs`\nconfiguration:\n\n    Livebook.config_runtime()","ref":"Livebook.html#config_runtime/0"},{"type":"function","title":"Livebook.live_markdown_to_elixir/1","doc":"Parses the given Live Markdown document and converts it to Elixir\nsource code.","ref":"Livebook.html#live_markdown_to_elixir/1"},{"type":"function","title":"Limitations - Livebook.live_markdown_to_elixir/1","doc":"Note that the resulting script may not compile in some cases, for\nexample if you define a macro in one cell and import it in another\ncell, it works fine in Livebook, because each cell is compiled\nseparately. However, when running the script it gets compiled as a\nwhole and consequently doing so doesn't work.\n\nAdditionally, branching sections are commented out.","ref":"Livebook.html#live_markdown_to_elixir/1-limitations"},{"type":"extras","title":"Welcome to Livebook","doc":"# Livebook\n\n[![Website](https://img.shields.io/badge/-Website-%23ff87a7)](https://livebook.dev/)\n[![Latest Version](https://img.shields.io/hexpm/v/livebook?color=b5a3be&label=Latest+version)](https://hexdocs.pm/livebook)\n\nLivebook is a web application for writing interactive and collaborative code notebooks. It features:\n\n  * Code notebooks with Markdown support and Code cells where Elixir code is evaluated on demand.\n\n  * Rich code editor through [CodeMirror](https://codemirror.net/): with support for autocompletion, inline documentation, code formatting, etc.\n\n  * Interactive results via [Kino](https://github.com/elixir-nx/kino): display [Vega-Lite charts](https://vega.github.io/vega-lite/), tables, maps, and more.\n\n  * Automation: use Smart cells to perform high-level tasks and write notebooks faster than ever. Query databases, plot charts, build maps, and more directly from Livebook's UI.\n\n  * Reproducible: Livebook ensures your code runs in a predictable order, all the way down to package management. It also tracks your notebook state, annotating which parts are stale.\n\n  * Collaboration: multiple users can work on the same notebook at once, no additional setup required.\n\n  * Decentralized: Livebook is open-source and you can run it anywhere. The [\"Run in Livebook\" badge](https://livebook.dev/badge) makes it easy to import any Livebook into your own Livebook.\n\n  * Versionable: notebooks are stored in the `.livemd` format, which is a subset of Markdown with support for diagrams via [Mermaid](https://mermaid-js.github.io/mermaid) and for mathematical formulas via [KaTex](https://katex.org/). `.livemd` files can be shared and play well with version control.\n\n  * Custom runtimes: when executing Elixir code, you can either start a fresh Elixir instance, connect to an existing node, or run it inside an existing Elixir project, with access to all of its modules and dependencies. This means Livebook can be a great tool to introspect and document existing projects too.","ref":"readme.html"},{"type":"extras","title":"Getting started - Welcome to Livebook","doc":"Head out to [the Install section](https://livebook.dev/#install) of Livebook's website to get started. Once Livebook is up and running on your machine, **visit the \"Learn\" section** with introductory guides and documentation on several Livebook features. Here is a sneak peak of the \"Welcome to Livebook\" guide:\n\n![Screenshot](https://github.com/livebook-dev/livebook/raw/main/.github/imgs/welcome.png)\n\nThere are more resources for those who are ready to dig deeper:\n\n  * [Our official documentation](https://hexdocs.pm/livebook/) with in-depth guides\n\n  * [Our Integrations page](https://livebook.dev/integrations/) covering the languages, data sources, and libraries that Livebook works with out-of-the-box\n\n  * [Our blog](https://news.livebook.dev/) with news, posts, and screencasts","ref":"readme.html#getting-started"},{"type":"extras","title":"Installation - Welcome to Livebook","doc":"We provide several methods for running Livebook,\npick the one that best fits your use case.","ref":"readme.html#installation"},{"type":"extras","title":"Desktop app - Welcome to Livebook","doc":"* [Download the installer for Mac and Windows from our homepage](https://livebook.dev/#install)\n\n  * Latest stable builds: [Mac (Universal)](https://github.com/livebook-dev/livebook/releases/latest/download/LivebookInstall-macos-universal.dmg),\n    [Windows](https://github.com/livebook-dev/livebook/releases/latest/download/LivebookInstall-windows-x86_64.exe)\n\n  * Nightly builds: [Mac (Universal)](https://github.com/livebook-dev/livebook/releases/download/nightly/LivebookInstall-macos-universal.dmg),\n    [Windows](https://github.com/livebook-dev/livebook/releases/download/nightly/LivebookInstall-windows-x86_64.exe)\n\n  * Builds for particular Livebook version are available on our\n    [GitHub releases](https://github.com/livebook-dev/livebook/releases).","ref":"readme.html#desktop-app"},{"type":"extras","title":"Docker - Welcome to Livebook","doc":"Running Livebook using Docker is another great option to run Livebook\nin case you don't have Elixir installed.\n\n```shell\n# Running with the default configuration\ndocker run -p 8080:8080 -p 8081:8081 --pull always ghcr.io/livebook-dev/livebook\n\n# In order to access and save notebooks directly to your machine\n# you can mount a local directory into the container.\n# Make sure to specify the user with \"-u $(id -u):$(id -g)\"\n# so that the created files have proper permissions\ndocker run -p 8080:8080 -p 8081:8081 --pull always -u $(id -u):$(id -g) -v $(pwd):/data ghcr.io/livebook-dev/livebook\n\n# You can configure Livebook using environment variables,\n# for all options see the dedicated \"Environment variables\" section below\ndocker run -p 8080:8080 -p 8081:8081 --pull always -e LIVEBOOK_PASSWORD=\"securesecret\" ghcr.io/livebook-dev/livebook\n\n# Or if you need to run on different ports:\ndocker run -p 8090:8090 -p 8091:8091 --pull always -e LIVEBOOK_PORT=8090 -e LIVEBOOK_IFRAME_PORT=8091 ghcr.io/livebook-dev/livebook\n```\n\nTo deploy Livebook on your cloud platform, see our [Docker Deployment](docs/deployment/docker.md) guide.\n\nFor CUDA support, [see images with the \"cuda\" tag](https://github.com/livebook-dev/livebook/pkgs/container/livebook).\n\nTo try out features from the main branch you can alternatively\nuse the `ghcr.io/livebook-dev/livebook:nightly` image.\nSee [Livebook images](https://github.com/livebook-dev/livebook/pkgs/container/livebook).","ref":"readme.html#docker"},{"type":"extras","title":"Embedded devices - Welcome to Livebook","doc":"If you want to run Livebook on embedded devices, such as Raspberry Pi, BeagleBone, etc.,\ncheck out [the Livebook firmware](https://github.com/nerves-livebook/nerves_livebook) built\nwith [Nerves](https://www.nerves-project.org/).","ref":"readme.html#embedded-devices"},{"type":"extras","title":"Direct installation with Elixir - Welcome to Livebook","doc":"You can run Livebook on your own machine using just Elixir. You will need\n[Elixir v1.18](https://elixir-lang.org/install.html) or later.\nLivebook also requires the following Erlang applications: `inets`,\n`os_mon`, `runtime_tools`, `ssl` and `xmerl`. Those applications come\nwith most Erlang distributions but certain package managers may split\nthem apart. For example, on Ubuntu, these Erlang applications can\nbe installed as follows:\n\n```shell\nsudo apt install erlang-inets erlang-os-mon erlang-runtime-tools erlang-ssl erlang-xmerl erlang-dev erlang-parsetools\n```\n\n**Note:** The [`livebook` package](https://hex.pm/packages/livebook)\nis meant to be used as a CLI tool. Livebook is not officially\nsupported as a Mix/Hex dependency.\n\n#### Escript\n\nRunning Livebook using Escript makes for a very convenient option\nfor local usage and provides easy configuration via CLI options.\n\n```shell\nmix do local.rebar --force, local.hex --force\nmix escript.install hex livebook\n\n# Start the Livebook server\nlivebook server\n\n# See all the configuration options\nlivebook server --help\n```\n\nAfter you install the escript, make sure you add the directory where\nElixir keeps escripts to your [$PATH](https://en.wikipedia.org/wiki/PATH_(variable)).\nIf you installed Elixir with `asdf`, you'll need to run `asdf reshim elixir`\nonce the escript is built.\n\nTo try out features from the main branch you can alternatively\ninstall the escript directly from GitHub like this:\n\n```shell\nmix escript.install github livebook-dev/livebook\n```\n\n#### From source\n\nYou can run latest Livebook directly from source.\n\n```shell\ngit clone https://github.com/livebook-dev/livebook.git\ncd livebook\nmix deps.get --only prod\n\n# Run the Livebook server\nMIX_ENV=prod mix phx.server\n```","ref":"readme.html#direct-installation-with-elixir"},{"type":"extras","title":"Security considerations - Welcome to Livebook","doc":"Livebook is built to document and execute code. Anyone with access to a Livebook instance\nwill be able to access any file and execute any code in the machine Livebook is running.\n\nFor this reason, Livebook only binds to the 127.0.0.1, allowing access to happen only within\nthe current machine. When running Livebook in the production environment - the recommended\nenvironment - we also generate a token on initialization and we only allow access to the\nLivebook if said token is supplied as part of the URL.","ref":"readme.html#security-considerations"},{"type":"extras","title":"Environment variables - Welcome to Livebook","doc":"<!-- Environment variables -->\n\nThe following environment variables can be used to configure Livebook on boot:\n\n  * `LIVEBOOK_ALLOW_URI_SCHEMES` - sets additional allowed hyperlink schemes to the\n    Markdown content. Livebook sanitizes links in Markdown, allowing only a few\n    standard schemes by default (such as http and https). Set it to a comma-separated\n    list of schemes.\n\n  * `LIVEBOOK_APP_SERVICE_NAME` - sets the application name used by the cloud\n    provider to aid debugging.\n\n  * `LIVEBOOK_APP_SERVICE_URL` - sets the application url to manage this\n    Livebook instance within the cloud provider platform.\n\n  * `LIVEBOOK_APPS_PATH` - the directory with app notebooks. When set, the apps\n    are deployed on Livebook startup with the persisted settings. Password-protected\n    notebooks will receive a random password, unless `LIVEBOOK_APPS_PATH_PASSWORD`\n    is set. When deploying using Livebook's Docker image, consider using\n    `LIVEBOOK_APPS_PATH_WARMUP`.\n\n  * `LIVEBOOK_APPS_PATH_PASSWORD` - the password to use for all protected apps\n    deployed from `LIVEBOOK_APPS_PATH`.\n\n  * `LIVEBOOK_APPS_PATH_WARMUP` - sets the warmup mode for apps deployed from\n    `LIVEBOOK_APPS_PATH`. Must be either \"auto\" (apps are warmed up on Livebook\n    startup, right before app deployment) or \"manual\" (apps are warmed up when\n    building the Docker image; to do so add \"RUN /app/bin/warmup_apps\" to\n    your image). Defaults to \"auto\".\n\n  * `LIVEBOOK_AWS_CREDENTIALS` - enable Livebook to read AWS Credentials from\n    environment variables, AWS Credentials, EC2/ECS metadata when configuring\n    S3 buckets.\n\n  * `LIVEBOOK_BASE_URL_PATH` - sets the base url path the web application is\n    served on. Useful when deploying behind a reverse proxy.\n\n  * `LIVEBOOK_PUBLIC_BASE_URL_PATH` - sets the base url path the `/public/*` routes\n    are served on. Note that this takes precedence over `LIVEBOOK_BASE_URL_PATH`,\n    if both are set. Setting this may be useful to create exceptions when deploying\n    behind a reverse proxy that requires authentication.\n\n  * `LIVEBOOK_CACERTFILE` - path to a local file containing CA certificates.\n    Those certificates are used during for server authentication when Livebook\n    accesses files from external sources.\n\n  * `LIVEBOOK_CLUSTER` - configures clustering strategy when running multiple\n    instances of Livebook using either the Docker image or an Elixir release.\n    See the \"Clustering\" docs for more information:\n    https://hexdocs.pm/livebook/clustering.html\n\n  * `LIVEBOOK_COOKIE` - sets the cookie for running Livebook in a cluster.\n    Defaults to a random string that is generated on boot.\n\n  * `LIVEBOOK_DATA_PATH` - the directory to store Livebook's internal\n    configuration. Defaults to \"livebook\" under the default user data\n    directory.\n\n  * `LIVEBOOK_DEFAULT_RUNTIME` - sets the runtime type that is used by default\n    when none is started explicitly for the given notebook. Must be either\n    \"standalone\" (Standalone), \"attached:NODE:COOKIE\" (Attached node)\n    or \"embedded\" (Embedded). Defaults to \"standalone\".\n\n  * `LIVEBOOK_FIPS` - if set to \"true\", it enables the FIPS mode on startup.\n    See more details in [the documentation](https://hexdocs.pm/livebook/fips.html).\n\n  * `LIVEBOOK_FORCE_SSL_HOST` - sets a host to redirect to if the request is not over HTTPS.\n    Note it does not apply when accessing Livebook via localhost. Defaults to nil.\n\n  * `LIVEBOOK_HOME` - sets the home path for the Livebook instance. This is the\n    default path used on file selection screens and others. Defaults to the\n    user's operating system home.\n\n  * `LIVEBOOK_IDENTITY_PROVIDER` - controls whether Zero Trust Authentication\n    must be used for this Livebook instance. This is useful when deploying\n    Livebook airgapped inside a cloud platform, such as Cloudflare and Google.\n    Supported values are:\n\n      * `basic_auth: : `\n      * `cloudflare: `\n      * `google_iap: `\n      * `tailscale: `\n      * `custom:YourElixirModule`\n\n    See our authentication docs for more information: https://hexdocs.pm/livebook/authentication.html\n\n  * `LIVEBOOK_IFRAME_PORT` - sets the port that Livebook serves iframes at.\n    This is relevant only when running Livebook without TLS. Defaults to 8081.\n\n  * `LIVEBOOK_IFRAME_URL` - sets the URL that Livebook loads iframes from.\n    By default iframes are loaded from local `LIVEBOOK_IFRAME_PORT` when accessing\n    Livebook over http:// and from https://livebookusercontent.com when accessing over https://.\n\n  * `LIVEBOOK_IP` - sets the ip address to start the web application on.\n    Must be a valid IPv4 or IPv6 address.\n\n  * `LIVEBOOK_LOG_LEVEL` - sets the logger level, allowing for more verbose\n    logging, either of: error, warning, notice, info, debug. Defaults to warning.\n\n  * `LIVEBOOK_LOG_METADATA` - a comma-separated list of metadata keys that should\n    be included in the log messages. Currently the only Livebook-spcecific key is\n    users (attached to evaluation and request logs). By default includes only\n    request_id.\n\n  * `LIVEBOOK_LOG_FORMAT` - sets the log output format, either \"text\" (default)\n    for human-readable logs or \"json\" for structured JSON.\n\n  * `LIVEBOOK_NODE` - sets the node name for running Livebook in a cluster.\n    Note that Livebook always runs using long names distribution, so the\n    node host name must use a fully qualified domain name (FQDN) or an IP\n    address.\n\n  * `LIVEBOOK_PASSWORD` - sets a password that must be used to access Livebook.\n    Must be at least 12 characters. Defaults to token authentication.\n\n  * `LIVEBOOK_PROXY_HEADERS` - a comma-separated list of headers that are set by\n    proxies. For example, `x-forwarded-for,x-forwarded-proto`. Configuring those\n    may be required when running Livebook behind reverse proxies.\n\n  * `LIVEBOOK_PORT` - sets the port Livebook runs on. If you want to run multiple\n    instances on the same domain with the same credentials but on different ports,\n    you also need to set `LIVEBOOK_SECRET_KEY_BASE`. Defaults to 8080. If set to 0,\n    a random port will be picked.\n\n  * `LIVEBOOK_SECRET_KEY_BASE` - sets a secret key that is used to sign and encrypt\n    the session and other payloads used by Livebook. Must be at least 64 characters\n    long and it can be generated by commands such as: `openssl rand -base64 48`.\n    Defaults to a random secret on every boot.\n\n  * `LIVEBOOK_SHUTDOWN_ENABLED` - controls if a shutdown button should be shown\n    in the homepage. Set it to \"true\" to enable it.\n\n  * `LIVEBOOK_TOKEN_ENABLED` - controls whether token authentication is enabled.\n    Enabled by default unless `LIVEBOOK_PASSWORD` is set. Set it to \"false\" to\n    disable it.\n\n  * `LIVEBOOK_UPDATE_INSTRUCTIONS_URL` - sets the URL to direct the user to for\n    updating Livebook when a new version becomes available.\n\n  * `LIVEBOOK_WITHIN_IFRAME` - controls if the application is running inside an\n    iframe. Set it to \"true\" to enable it. If you do enable it, then the application\n    must run with HTTPS.\n\nThe environment variables `ERL_AFLAGS` and `ERL_ZFLAGS` can also be set to configure\nLivebook and the notebook runtimes. `ELIXIR_ERL_OPTIONS` are also available to customize\nLivebook, but it is not forwarded to runtimes.\n\n<!-- Environment variables -->\n\nIf running Livebook via the command line, run `livebook server --help` to see\nall CLI-specific options.","ref":"readme.html#environment-variables"},{"type":"extras","title":"Livebook Desktop - Welcome to Livebook","doc":"When running Livebook Desktop, Livebook will invoke on boot a file named\n`~/.livebookdesktop.sh` on macOS or `%USERPROFILE%\\.livebookdesktop.bat`\non Windows. This file can set environment variables used by Livebook,\nsuch as:\n\n  * [the `PATH` environment variable](https://en.wikipedia.org/wiki/PATH_(variable))\n\n  * or to configure the Erlang VM, for instance, by setting\n    `ERL_AFLAGS=\"-proto_dist inet6_tcp\"` if you need Livebook to run over IPv6\n\nBe careful when modifying boot files, Livebook may be unable to start if\nconfigured incorrectly.","ref":"readme.html#livebook-desktop"},{"type":"extras","title":"Development - Welcome to Livebook","doc":"Livebook is primarily a Phoenix web application and can be setup as such:\n\n```shell\ngit clone https://github.com/livebook-dev/livebook.git\ncd livebook\nmix setup\n\n# Run the Livebook server\nmix phx.server\n\n# Run tests\nmix test\n```","ref":"readme.html#development"},{"type":"extras","title":"Acknowledgements - Welcome to Livebook","doc":"Thank you to [Uffizzi](https://www.uffizzi.com) for providing ephemeral environments to preview pull requests.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"Desktop app builds - Welcome to Livebook","doc":"For macOS, run:\n\n```shell\n# Test macOS app locally\n(cd rel/app/macos && ./run.sh)\n\n# Build macOS installer\n.github/scripts/app/build_macos.sh\n```\n\nFor Windows, run:\n\n```shell\n# Test Windows app locally\n(cd rel/app/windows && ./run.sh)\n\n# Build Windows installer\n.github/scripts/app/build_windows.sh\n```","ref":"readme.html#desktop-app-builds"},{"type":"extras","title":"Platinum sponsors - Welcome to Livebook","doc":"Fly is a platform for running full stack apps and databases close to your users.","ref":"readme.html#platinum-sponsors"},{"type":"extras","title":"Sponsors - Welcome to Livebook","doc":"The platform where the machine learning community \ncollaborates on models, datasets, and applications.\n\n \n\n \n   \n     \n     \n     \n   \n \n\nTigris is a globally distributed S3-compatible object storage \nservice that provides low latency anywhere in the world.","ref":"readme.html#sponsors"},{"type":"extras","title":"License - Welcome to Livebook","doc":"Copyright (C) 2021 Dashbit\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Use cases","doc":"# Use cases\n\nThere are many ways Elixir developers use and leverage Livebook today.","ref":"use_cases.html"},{"type":"extras","title":"Documentation with `Mix.install` - Use cases","doc":"Livebook is an excellent tool for documentation. Many Elixir packages use\nLivebook as tutorials but you can also directly run Livebook within the context\nof your existing application with the help of `Mix.install/2`.\n\nAs an example, imagine you have created a notebook inside your current project,\nat `notebooks/example.livemd`. In order to run within the root Mix project, using\nthe same configuration and dependencies versions, you can change your notebook\nsetup cell to invoke `Mix.install/2` with the following arguments:\n\n```elixir\nMix.install(\n  [\n    {:my_app, path: Path.join(__DIR__, \"..\"), env: :dev}\n  ],\n  config_path: :my_app,\n  lockfile: :my_app\n)\n```","ref":"use_cases.html#documentation-with-mix-install"},{"type":"extras","title":"Deploying custom apps and internal tooling - Use cases","doc":"Your Livebook notebooks can be deployed as applications which\nyou may then share within your team and company. Docker deployment\nis provided out of the box and you can automate your deployment,\nshare secrets, configure authentication and more with\n[Livebook Teams](https://livebook.dev/teams).","ref":"use_cases.html#deploying-custom-apps-and-internal-tooling"},{"type":"extras","title":"Communication and automation of Elixir systems - Use cases","doc":"You may also deploy notebooks as applications that automate and monitor\nlive Elixir systems. By clicking on \"+ Smart cell\", you will find Livebook\nprovides a \"Remote execution\" widget, that allows you to configure the\nnode name, cookie, and the code you want to execute on the remote node.\n\nThe node and cookie information are configured directly in the production\nsystem you want to connect to. For example, to connect to a\n[Phoenix application](https://phoenixframework.org/) running on your machine,\nyou may start it as follows:\n\n```shell\n$ iex --name phoenix-app@127.0.0.1 --cookie secret -S mix phx.server\n```\n\nWith this information in hand, you can query and automate tasks within\nexisting Elixir systems. You may also mix remote execution with Livebook's\nrich features to deploy applications that interact with those systems.","ref":"use_cases.html#communication-and-automation-of-elixir-systems"},{"type":"extras","title":"Debugging live systems (with attached mode) - Use cases","doc":"Livebook uses the concept of a **runtime**, which in practice is an Elixir node\nresponsible for evaluating your code. You can choose the runtime by clicking\nthe \"Runtime\" icon on the sidebar (or by using the `s` `r` keyboard shortcut).\n\nBy default, a new Elixir runtime is started (similarly to starting `iex`)\nfor each notebook. You can click reconnect whenever you want to discard the\ncurrent runtime and start a new one.\n\nYou can also manually *attach* to an existing node by picking the \"Attached Node\"\nruntime. While in the previous section we used the \"Remote execution\" smart cell\nto connect the default Livebook runtime to an existing node, the \"Attached Node\"\nwill make it so the Livebook runtime itself runs within the external node.\n\nTo do so, open up a new notebook and click the \"Runtime\" icon on the sidebar.\nClick to \"Configure\" the runtime and choose \"Attached node\". Input the\nname and cookie from the remote node and you should be ready to connect\nto it. Once connected, be careful: any code that you execute in the notebook\nnow runs within the connected application. You are also limited on actions\nyou may perform. For example, you can't install dependencies (nor would that\nbe a good idea on a running system).\n\nYou may also [connect your local Livebook instance to a node running in\nproduction depending on your platform](https://fly.io/docs/elixir/advanced-guides/connect-livebook-to-your-app/).","ref":"use_cases.html#debugging-live-systems-with-attached-mode"},{"type":"extras","title":"Scaffolding embedded systems with Nerves - Use cases","doc":"If you want to run Livebook on embedded devices, such as Raspberry Pi,\nBeagleBone, etc., check out [the Livebook\nfirmware](https://github.com/nerves-livebook/nerves_livebook) built\nwith [Nerves](https://www.nerves-project.org/). In such cases, Livebook\nuses a special runtime, called the Embedded Runtime, where all of your\ncode runs within Livebook itself, without starting additional runtimes\n(which may be too expensive on limited devices).","ref":"use_cases.html#scaffolding-embedded-systems-with-nerves"},{"type":"extras","title":"Ready to get started? - Use cases","doc":"Head out to [Livebook homepage](https://livebook.dev/) to install it.\nOnce you have it up and running, head to the \"Learn\" section on the\nsidebar to learn more!","ref":"use_cases.html#ready-to-get-started"},{"type":"extras","title":"Authentication","doc":"# Authentication\n\nLivebook has three levels of authentication:\n\n  * **Instance authentication**: this authenticates the user on all routes of your Livebook instance, including deployed notebooks and the admin section. We provide a variety of authentication options here, including Single Sign On (SSO) and domain-based authentication via [Livebook Teams](https://livebook.dev/teams), as well as Zero Trust Authentication for airgapped environments. See the \"Instance authentication\" section for more information.\n\n  * **Admin authentication**: this authenticates access to Livebook admin interface within an instance, where users can create, write, and manage notebooks. Both password and token authentication are available. See the [\"Admin authentication\"](#admin-authentication) section for more information.\n\n  * **Deployed notebook passwords**: additionally, when deploying notebooks as applications, each application may be password protected with a unique password. Only users authenticated as admin or with the password will be able to access them.","ref":"authentication.html"},{"type":"extras","title":"Instance authentication - Authentication","doc":"When using [Livebook Teams](https://livebook.dev/teams), you can easily deploy instances of Livebook to run as application servers or as development servers. Those instances will, by default, use Livebook Teams to authenticate. The following authentication methods are supported by Livebook Teams:\n\n* **Livebook Teams account**: allow members of your Livebook Teams organization to authenticate using their Livebook Teams accounts.\n\n* **Email domain**: allow users to authenticate using email accounts from specific domains, such as your company’s Google Workspace domain.\n\n* **[OpenID Connect Single Sign-On (SSO)](/oidc_sso.html)**: Allow users to authenticate via an OpenID Connect Single Sign-On provider, such as Okta, Microsoft Entra or Keycloak.\n\nIf your application servers must run in an airgapped environments and cannot reach out to Livebook Teams servers, we also provide a variety of options that can be configured directly in your Dockerfiles. See the \"Airgapped Authentication\" section in the sidebar.","ref":"authentication.html#instance-authentication"},{"type":"extras","title":"Admin authentication - Authentication","doc":"Livebook's default admin authentication method is token authentication. A token is automatically generated at startup and printed to the logs.\n\nYou may optionally enable password-based authentication by setting the environment variable `LIVEBOOK_PASSWORD` on startup or deployment. It must be at least 12 characters.\n\nTo disable admin authentication, you may set the environment variable `LIVEBOOK_TOKEN_ENABLED` to `false`.","ref":"authentication.html#admin-authentication"},{"type":"extras","title":"Notebook stamping","doc":"# Notebook stamping\n\nLivebook provides a feature called \"Notebook Stamping\", with the goal of enhancing security and productivity within notebooks.\n\nWhenever you author a notebook, the contents of the notebook is signed with a secret key that belongs to your machine (which you can also find in settings). If the notebook accesses any secret or file system configuration, these permissions are stored within the stamp.\n\nWhenever you open up a notebook stamped by you, it will retain access to secrets and file systems, and you won't have to reenable them. Whenever you open up a notebook stamped by someone else, a warning is displayed, all access is revoked, and must be explicitly enabled. However, remember that stamping only takes care of Livebook resources: when you execute the notebook, the code in the notebook will still have access to the current machine, so always execute third-party code with care.\n\nNote that deploying notebooks as applications do not verify stamps when using your personal workspace. For such, you must use Livebook Teams, which provides an authority for stamping and encrypting notebooks.","ref":"stamping.html"},{"type":"extras","title":"Secure deployments with Livebook Teams - Notebook stamping","doc":"When using Livebook Teams, notebooks are stamped with a private key that belongs to your organization/workspace. This means you can share notebooks within your organization, and if the notebook accesses any secret/file system resource, the access rules are transparently retained.\n\nFurthermore, when deploying with Livebook Teams, Livebook guarantees that all of the notebooks belong to your organization and that the stamps are valid, eliminating the chance that someone in your organization accidentally deploys an external notebook that has not been previously reviewed by a team member.\n\nLivebook Teams stamping works in two steps:\n\n1. The notebook is encrypted using your Livebook Teams key and then sent to the Livebook Teams server. Since Livebook Teams do not have access to your Livebook Teams key, Livebook Teams cannot read the content of your notebooks\n\n2. The Livebook Teams server then stamps the encrypted notebook using a private key, that is only available within Livebook Teams server. The members of your organization only have access to the public key, which validates the stamp, without giving past or future employees the option to forge stamps\n\nThe steps above ensure that the contents are only visible to your team members and only team members with access to the Livebook Teams can stamp notebooks.","ref":"stamping.html#secure-deployments-with-livebook-teams"},{"type":"extras","title":"Intro to Livebook Teams","doc":"# Intro to Livebook Teams\n\n[Livebook Teams](https://livebook.dev/teams/?ref=docs) enables you to deploy Livebook apps to your own infrastructure.\n\n  \n\nBesides deployment automation, it also offers the following features:\n\n- Authentication via multiple identity providers:\n\t- Livebook Teams\n\t- [Email-domain (Google, Microsoft, etc)](email_domain.md)\n\t- [OIDC (Okta, Microsoft Entra, etc)](oidc_sso.md)\n- Authorization\n\t- [based on groups from an OIDC identity provider (Okta, Microsoft Entra, etc)](oidc_groups.md)\n- [Shared Livebook secrets](shared_secrets.md)\n- [Shared Livebook file storages](shared_file_storages.md)\n\nYou can [start a free trial here](https://livebook.dev/teams/?ref=docs).","ref":"intro_to_teams.html"},{"type":"extras","title":"Deploy Livebook apps","doc":"# Deploy Livebook Apps with Livebook Teams\n\nThis tutorial guides you through deploying a Livebook app using Livebook Teams. By the end, you'll have deployed a notebook as an interactive web app running in a local server.","ref":"deploy_app.html"},{"type":"extras","title":"Prerequisites - Deploy Livebook apps","doc":"Before you begin, make sure you have:\n\n- A [Livebook Teams](https://livebook.dev/teams) account\n- Membership in a Livebook Teams organization\n- Docker installed\n\nIf you're not part of a Teams org, here's a [one-minute video showing how to create one](https://www.youtube.com/watch?v=Ox8-JT0JHO4).","ref":"deploy_app.html#prerequisites"},{"type":"extras","title":"Step 1: Open our example notebook - Deploy Livebook apps","doc":"For this tutorial, we'll use our example notebook that contains a Livebook app.\n\n1. Open Livebook in your browser\n2. Click the **Open** button to open a notebook\n3. Click the **From URL** tab to open a notebook from a URL\n4. Enter the URL of our example app in the notebook URL field: `https://teams.livebook.dev/notebooks/github_stars`\n5. Click the **Import** button\n\nYou should see the \"GitHub Stars\" notebook opened:\n\n![github stars livebook notebook](images/github_stars_notebook.png)","ref":"deploy_app.html#step-1-open-our-example-notebook"},{"type":"extras","title":"Step 2: Preview the app locally - Deploy Livebook apps","doc":"Before deploying the app, let's preview what it looks like.\n\n1. Click the **App Settings** icon in the sidebar\n2. Click the **Launch preview** button to run your notebook as an app\n3. Click the URL of your local app preview to open the app\n\nYou should see your app running inside Livebook. Something like this:\n\n![app preview](images/app_preview.png)\n\nNotice how the notebook is now running as a web app, with all code hidden, showing just the UI widgets and outputs.","ref":"deploy_app.html#step-2-preview-the-app-locally"},{"type":"extras","title":"Step 3: Set up a deployment group - Deploy Livebook apps","doc":"Before you can deploy a Livebook app, we need to configure a [deployment group](teams_concepts.md#deployment-groups)\nfor your Teams org. Let's do that.\n\nFirst, go back to your notebook. Then:\n\n1. Click the **App Settings** icon in the sidebar\n2. Click the **Deploy with Livebook Teams** button\n3. If the notebook is not open within your Teams organization's workspace, you'll be asked to change the workspace to your organization's workspace. Do that if needed and click the \"Deploy with Livebook Teams\" button again.\n\nYou should now see a form to create a deployment group, like this:\n\n![deployment group form](images/deployment_group_form.png)\n\nLet's complete this form to create our deployment group.\n\n1. For the **Name** input, let's use \"local test\".\n2. For the **Clustering** select, change to \"Single instance\"\n3. Click the **Add** button\n\nNow we're ready for the final configuration step: setting up a Livebook app server.","ref":"deploy_app.html#step-3-set-up-a-deployment-group"},{"type":"extras","title":"Step 4: Set up a Livebook app server - Deploy Livebook apps","doc":"After completing the previous step, you should see a modal like this:\n\n![app server setup instructions](images/app_server_setup.png)\n\nThis modal contains instructions to set up an [app server](teams_concepts.md#app-server). Let's do it.\n\nThe easiest way to set up an app server is to run it as a Docker container. You can do that in any\nserver infrastructure that runs Docker, such as Fly.io or a Kubernetes cluster.\n\nFor our tutorial, we'll set up our app server running in a local Docker container. To do that,\ncopy and paste the CLI command provided by Livebook. The instructions look something\nlike this:\n\n![CLI command to run an Livebook app server with Docker](images/app_server_docker.png)\n\n> #### Use available host ports {: .tip}\n>\n> You may need to change the host ports in the Docker CLI command if ports\n> 8080 or 8081 are already in use on your machine. Here's how:\n>\n> ```\n> # Instead of using the default host ports, 8080 and 8081.\n> docker run -p 8080:8080 -p 8081:8081 (rest of the command...)\n> ```\n>\n> ```\n> # You can map to different host ports like 9080 and 9081\n> docker run -p 9080:8080 -p 9081:8081 (rest of the command...)\n> ```\n\nOnce you run the CLI command in your terminal, Docker will download the Livebook image and run it. Wait until that's done.\n\nOnce the container is ready, a Livebook instance will start and automatically connect to your Livebook Teams organization. Livebook will display a message confirming that an app server is now running and connected to your Teams organization, like this:\n\n![feedback message saying the app server is running](images/app_server_setup_message.png)\n\nNow we're ready to deploy our app!","ref":"deploy_app.html#step-4-set-up-a-livebook-app-server"},{"type":"extras","title":"Step 5: Deploy the app - Deploy Livebook apps","doc":"Once your app server is up and running, return to Livebook. You should see a **Deploy** button like this:\n\n![Deploy button](images/deploy_button.png)\n\nClick the button to deploy your Livebook app to your local app server.\n\nNow let's access the deployed app. If you used the default host port 8080 in the Docker command, access your app server at `http://localhost:8080`. If you used a different port, adjust the URL accordingly.\n\nOnce you access it, you will be asked to authenticate. Use the built-in \"Sign in with Livebook Teams\" authentication mechanism. It will use your Livebook Teams account to authenticate to your app server:\n\n![authentication](images/app_server_authentication.png)\n\nAfter you sign in, you'll be redirected to your app server, where you'll see the list of deployed\napps, like this:\n\n![deployed apps](images/deployed_apps.png)\n\nNotice how our deployed app is already there in the list.\n\nTo access the app, click on its title. You should now see the app running inside your app server:\n\n![deployed app running](images/deployed_app.png)\n\nThat's it, you deployed a Livebook app with Livebook Teams! 🎉","ref":"deploy_app.html#step-5-deploy-the-app"},{"type":"extras","title":"Deploying new versions of your app - Deploy Livebook apps","doc":"When you want to update your deployed app:\n\n1. Open the notebook and make your changes\n2. Click the **App Settings** icon in the sidebar\n3. Click the **Deploy with Livebook Teams** button\n4. Select your existing deployment group\n5. Click **Deploy**\n\nThat's it! A new version of your app will be deployed to your app server.\n\nTry it now by changing the title of your notebook and deploying it again.","ref":"deploy_app.html#deploying-new-versions-of-your-app"},{"type":"extras","title":"What you've learned - Deploy Livebook apps","doc":"You've successfully deployed a Livebook app with Livebook Teams! Along the way, you:\n\n- Ran a Livebook notebook as an interactive web app\n- Created a deployment group to organize your app deployments\n- Set up a Livebook app server using Docker\n- Deployed your app with a single click\n- Accessed your deployed app through Teams authentication\n- Learned how to update your app by redeploying\n\nYou now have the foundation to deploy Livebook apps for your team's internal tools.","ref":"deploy_app.html#what-you-ve-learned"},{"type":"extras","title":"What's next? - Deploy Livebook apps","doc":"Now that you've successfully deployed a Livebook app to a local app server, you might want to explore deploying to an app server running in the cloud. It's very similar to what we did before.\n\nI'll leave this as an exercise for you, the path goes like this:\n\n1. Go to the home page of your Livebook\n2. In the sidebar, click on your Teams workspace\n3. Scroll to the **Deployment groups** section of your workspace, you should see something like this:\n\n![deployment groups of a Teams workspace](images/deployment_groups_inside_workspace.png)\n\nNow, click the **Add deployment group** button and fill in the form to create a new deployment group, like we did in [Step 3](#step-3-set-up-a-deployment-group), but now let's use \"staging\" as the name of the deployment group.\n\nOnce you create this new deployment group, you'll see there's a **+Deploy** link for that deployment group:\n\n![add app server to deployment group](images/add_app_server_to_deployment_group.png)\n\nClick the **+Deploy** link of your staging deployment group to add an app server to it. You should see instructions for different ways to set up an app server:\n\n![instructions to set up an app server](images/instructions_setup_app_server.png)\n\nYou can use the Docker instructions to set up an app server in any cloud infrastructure that\nsupports Docker. There are also specific instructions for Fly.io and Kubernetes. Use the one you prefer.\n\n> **Want to understand the concepts?** If you'd like to learn more about deployment groups and app servers, check out our [concepts page](teams_concepts.md) after completing this tutorial.","ref":"deploy_app.html#what-s-next"},{"type":"extras","title":"Email domain auth","doc":"# Authentication via email domain\n\nEmail domain authentication allows you to authenticate users based on their email domain when they access your app servers and Livebook apps. For example, your users can access your Livebook apps using their company email accounts.\n\n![](images/email_domain_auth.png)\n\nCurrently, this feature supports only Google emails. If you need to use another email provider, [contact our support team](mailto:support@livebook.com?subject=Feature%20request%3A%20Additional%20email%20provider).\n\n> #### Livebook version requirement {: .info}\n> Requires Livebook v0.15 or newer.","ref":"email_domain.html"},{"type":"extras","title":"Demo - Email domain auth","doc":"Here's a quick demo of the feature:","ref":"email_domain.html#demo"},{"type":"extras","title":"Configuration - Email domain auth","doc":"","ref":"email_domain.html#configuration"},{"type":"extras","title":"1. Register your email domain - Email domain auth","doc":"To set up email domain authentication for your organization:\n\n1. Log in to Livebook Teams\n2. Navigate to the **Authentication** panel (requires \"admin\" role in the organization)\n3. Find the **Email domain** section\n4. Click **Configure**\n5. Enter your company's email domain(s):\n   - Add one domain per line (e.g., `acme.com`)\n   - You can add multiple domains if needed\n6. Save your changes","ref":"email_domain.html#1-register-your-email-domain"},{"type":"extras","title":"2. Configure your deployment group to authenticate via Livebook Teams - Email domain auth","doc":"To enable email domain authentication, your deployment group must be configured to use authentication via Livebook Teams.\n\n  \n\nIn order to do so, follow these steps:\n\n1. Log in to Livebook Teams\n2. Navigate to the **Deployments** panel\n3. Click **Edit** on the deployment group where you want to enable authentication\n4. Ensure that **Authenticate via Livebook Teams** is enabled.\n5. Save your changes","ref":"email_domain.html#2-configure-your-deployment-group-to-authenticate-via-livebook-teams"},{"type":"extras","title":"Test the integration - Email domain auth","doc":"To verify the integration is working, follow these steps:\n\n1. Navigate to an application deployed in a deployment group configured with email domain authentication\n2. The app server will redirect you to Livebook Teams for authentication\n3. On the authentication page, you will see an option to sign in using your email provider\n4. Click the name of your email provider and follow the authentication steps\n5. Once authentication is complete, your email provider will redirect you back to your app server, and you will be successfully signed in","ref":"email_domain.html#test-the-integration"},{"type":"extras","title":"OIDC SSO","doc":"# OIDC SSO (OpenID Connect Single Sign-On)\n\nLivebook Teams supports OpenID Connect (OIDC) Single Sign-On, allowing you to authenticate users through your existing Identity Provider (IdP) when they access your app servers and Livebook apps.\n\n![](images/auth_via_teams.png)\n\n> #### Livebook version requirement {: .info}\n> Requires Livebook v0.15 or newer.","ref":"oidc_sso.html"},{"type":"extras","title":"Demo - OIDC SSO","doc":"Here's a quick demo of the feature working.","ref":"oidc_sso.html#demo"},{"type":"extras","title":"Configuration - OIDC SSO","doc":"To integrate Livebook Teams with your OIDC SSO provider, follow these steps.","ref":"oidc_sso.html#configuration"},{"type":"extras","title":"1. Register with your OIDC Provider - OIDC SSO","doc":"Go to your IdP admin, and register Livebook Teams as a Relying Party (client/app). This is the info you’ll need from Livebook Teams:\n\n- **Redirect URI**: The Livebook Teams sign-in callback URL that must be registered with your IdP: ` https://teams.livebook.dev/identity/callbacks/oidc`\n- **Post Logout Redirect URI**: The Livebook Teams URL that must be registered with your IdP to redirect users after logout: `https://teams.livebook.dev/identity/logout`\n- **Required OIDC scopes**: the OIDC scopes Livebook Teams requires: `openid`, `profile`, `email`, `offline_access`\n\nOnce that’s done, you should retrieve the following information from the registration process:\n\n- **Client ID**: A unique identifier assigned to Livebook Teams by your IdP\n- **Client Secret**: A confidential key assigned to Livebook Teams by your IdP\n- **Discovery URL**: This is the OIDC metadata URL provided by your IdP. Usual format: `https://YOUR_IDP/.well-known/openid-configuration`","ref":"oidc_sso.html#1-register-with-your-oidc-provider"},{"type":"extras","title":"2. Configure OIDC in Livebook Teams - OIDC SSO","doc":"1. Log in to Livebook Teams\n2. Go to the **Authentication** panel (requires \"admin\" role in the organization)\n3. Click **Add OIDC SSO** and provide the following details:\n\t- **Name**: A display name for your OIDC provider (e.g., Okta, Microsoft Entra, Keycloak)\n\t- **Discovery URL**: Use the discovery URL retrieved from your IdP\n\t- **Client ID**: Use the Client ID retrieved from your IdP\n\t- **Client Secret**: Use the Client Secret retrieved from your IdP\n\t- **Enable this SSO provider**: Make sure this option is enabled\n4. Save","ref":"oidc_sso.html#2-configure-oidc-in-livebook-teams"},{"type":"extras","title":"3. Configure your deployment group to authenticate via Livebook Teams - OIDC SSO","doc":"To enable OIDC authentication, your deployment group must be configured to use authentication via Livebook Teams.\n\n  \n\nIn order to do so, follow these steps:\n\n1. Log in to Livebook Teams\n2. Navigate to the **Deployments** panel\n3. Click **Edit** on the deployment group where you want to enable authentication\n4. Ensure that **Authenticate via Livebook Teams** is enabled\n5. Save your changes","ref":"oidc_sso.html#3-configure-your-deployment-group-to-authenticate-via-livebook-teams"},{"type":"extras","title":"Test the integration with your OIDC IdP - OIDC SSO","doc":"To verify the integration is working, follow these steps:\n\n1. Navigate to an application deployed in a deployment group configured for OIDC authentication.\n2. The app server will redirect you to Livebook Teams for authentication\n3. On the authentication page, you will see an option to sign in using your configured OIDC provider\n4. Click the name of your OIDC SSO configuration and follow the authentication steps provided by your IdP\n5. Once authentication is complete, the IdP will redirect you back to your app server, and you will be successfully signed in","ref":"oidc_sso.html#test-the-integration-with-your-oidc-idp"},{"type":"extras","title":"OIDC groups authorization","doc":"# OIDC groups authorization\n\nLivebook Teams allows you to control access to your app servers and Livebook apps based on group membership in your OIDC identity provider (IdP).\n\n![](images/oidc_groups_auth.png)\n\n> #### Livebook version requirement {: .info}\n> Requires Livebook v0.16 or newer.","ref":"oidc_groups.html"},{"type":"extras","title":"Overview - OIDC groups authorization","doc":"OIDC groups authorization enables you to:\n\n- Restrict access to your Livebook apps and app servers based on group membership\n- Control which users can access specific apps using slug prefix filtering\n- Integrate seamlessly with your existing OIDC SSO provider (Okta, Microsoft Entra, etc.)","ref":"oidc_groups.html#overview"},{"type":"extras","title":"Prerequisites - OIDC groups authorization","doc":"Before configuring OIDC groups authorization, ensure you have:\n\n1. **Configured an OIDC provider** in your Livebook Teams organization. If you haven't done this yet, follow the instructions in our [OIDC SSO documentation](oidc_sso.md).\n\n2. **Configured your OIDC identity provider** to include group information in the ID tokens:\n   - **Okta**: [Customize tokens with a groups claim](https://developer.okta.com/docs/guides/customize-tokens-groups-claim/main/)","ref":"oidc_groups.html#prerequisites"},{"type":"extras","title":"Configuration - OIDC groups authorization","doc":"","ref":"oidc_groups.html#configuration"},{"type":"extras","title":"1. Enable authorization via OIDC SSO groups - OIDC groups authorization","doc":"To enable authorization via OIDC SSO groups for a deployment group:\n\n1. Log in to Livebook Teams\n2. Navigate to the **Deployments** panel\n3. Click **Edit** on the deployment group where you want to enable authorization\n4. Go to the **IAM** section (requires \"admin\" role in the organization)\n5. Ensure that **Authenticate via Livebook Teams** is enabled\n6. Enable **Authorize via OIDC SSO groups**","ref":"oidc_groups.html#1-enable-authorization-via-oidc-sso-groups"},{"type":"extras","title":"2. Add group authorization - OIDC groups authorization","doc":"Once authorization is enabled, you can add group access rules:\n\n1. Click the **Add group** button\n2. Select one of your configured OIDC identity providers\n3. Enter the name of a group from your identity provider\n4. Choose the **Access type**:\n   - Full access\n   - Slug prefix access\n5. Click the **Add group** button to save the rule\n\nYou can add multiple groups with different access types to configure your authorization strategy.","ref":"oidc_groups.html#2-add-group-authorization"},{"type":"extras","title":"Access types explained - OIDC groups authorization","doc":"","ref":"oidc_groups.html#access-types-explained"},{"type":"extras","title":"Full access - OIDC groups authorization","doc":"Users who belong to groups with full access can access:\n- The app server admin interface*\n- All Livebook apps deployed to this deployment group\n\n**Notice that [Admin authentication](authentication.md#admin-authentication) configs will also apply if configured.*","ref":"oidc_groups.html#full-access"},{"type":"extras","title":"Slug prefix access - OIDC groups authorization","doc":"Users who belong to groups with slug prefix access can only access Livebook apps whose URL slugs start with the specified prefix.\n\nFor example, with the slug prefix \"**finance-**\", users can access an app whose slug is \"**finance-**budget\", but not one with the slug \"**hr-**budget\".\n\nThis allows you to create role-based access control based on your organization's existing group structure.","ref":"oidc_groups.html#slug-prefix-access"},{"type":"extras","title":"Testing the Configuration - OIDC groups authorization","doc":"To verify the configuration is working:\n\n1. Sign out of any current Livebook Teams sessions\n2. Navigate to an app server or Livebook app in the deployment group where you've enabled OIDC groups authorization\n3. You will be prompted to authenticate through your OIDC provider\n4. After authentication, the system will check your group membership\n5. You will only be granted access if you belong to one of the configured groups with appropriate permissions","ref":"oidc_groups.html#testing-the-configuration"},{"type":"extras","title":"Troubleshooting - OIDC groups authorization","doc":"If users are experiencing access issues:\n\n1. Verify the group name matches exactly as defined in your IdP (group names are case-sensitive)\n2. Check that the user is a member of the specified group in your IdP\n3. Ensure your OIDC provider is properly set up to include group names inside the ID token","ref":"oidc_groups.html#troubleshooting"},{"type":"extras","title":"Shared secrets management","doc":"# Shared secrets management","ref":"shared_secrets.html"},{"type":"extras","title":"Overview - Shared secrets management","doc":"This feature allows your team to share Livebook secrets among team members in an easy way.\n\nJust add a secret to your organization workspace, and Livebook Teams will synchronize it with the Livebook of every member of your organization.\n\n![](images/add_shared_secret.png)\n\nYou can also create such secrets directly from a notebook.\n\n![](images/add_shared_secret_from_notebook.png)\n\nShared secrets updates and deletions will also be synchronized.","ref":"shared_secrets.html#overview"},{"type":"extras","title":"How it works - Shared secrets management","doc":"Here's a video showing how that feature works.","ref":"shared_secrets.html#how-it-works"},{"type":"extras","title":"Security strengths - Shared secrets management","doc":"Livebook Teams cannot access the plain text version of your organization's secrets.\n\nLivebook encrypts your secrets locally in your machine using your Teams key. Then, the secret is sent encrypted to Livebook Teams servers.\n\nWhen a new synchronization is needed, Livebook Teams sends the encrypted secret to the Livebook of team members, and their Livebook decrypts the secret in their local machines using the same Teams key.","ref":"shared_secrets.html#security-strengths"},{"type":"extras","title":"Shared file storages","doc":"# Shared file storages","ref":"shared_file_storages.html"},{"type":"extras","title":"Overview - Shared file storages","doc":"This feature allows your team to share the configuration of S3-compatible storages.\n\nLivebook file storages are used to store notebooks and their files.\n\nWhenever you add (update or detach) a file storage to your organization workspace, Livebook Teams will synchronize that with the Livebook of every member of your organization.\n\n![](images/add_shared_file_storage.png)","ref":"shared_file_storages.html#overview"},{"type":"extras","title":"How it works - Shared file storages","doc":"Here's a video showing how that feature works.","ref":"shared_file_storages.html#how-it-works"},{"type":"extras","title":"Security strengths - Shared file storages","doc":"Livebook Teams cannot access the credentials of your S3 (compatible) account.\n\nLivebook encrypts your S3 credentials locally in your machine using your Teams key. Then, they're sent encrypted to Livebook Teams servers.\n\nWhen a new synchronization is needed, Livebook Teams sends the encrypted credentials to the Livebook of team members, and their Livebook decrypts that in their local machines using the same Teams key.","ref":"shared_file_storages.html#security-strengths"},{"type":"extras","title":"Livebook Teams concepts","doc":"# Understanding Livebook Teams concepts\n\nThis page explores the key concepts of Livebook Teams.","ref":"teams_concepts.html"},{"type":"extras","title":"Deployment group - Livebook Teams concepts","doc":"A deployment group serves as an organizational and configuration layer for your app servers and Livebook applications. Think of it as defining a \"deployment context\"—a set of rules, configurations, and boundaries that determine where your apps are deployed and how they can be accessed.\n\nA deployment group serves multiple purposes:\n\n1. **Logical separation**: A deployment group provides logical separation. One example is using different deployment groups for different environments, like staging and production. Or you can use different deployment groups for different departments of a company, like engineering and customer support.\n\n2. **Grouping app servers**: A deployment group contains one or more app servers.\n\n3. **IAM Configuration**: A deployment group contains the Identity and Access Management (IAM) configuration that is applied to all app servers belonging to it.","ref":"teams_concepts.html#deployment-group"},{"type":"extras","title":"App server - Livebook Teams concepts","doc":"A Livebook app server is a Livebook instance configured to act as an application server where you can deploy Livebook apps via Livebook Teams.\n\nIt's the same Livebook you can run on your machine, but with a few environment variable configurations that make that instance connect to an organization from Livebook Teams.\n\nSince it's a standard Livebook instance, you can also use it to create, open, and run regular notebooks in addition to serving as a deployment target for apps.","ref":"teams_concepts.html#app-server"},{"type":"extras","title":"The app server lifecycle - Livebook Teams concepts","doc":"When you start an app server, it:\n\n1. Connects to the Livebook Teams organization, using its server key to connect to a specific deployment group\n2. Downloads and runs all apps that are deployed to that deployment group\n3. Waits to receive app deployments and configuration changes from its organization and deployment group\n\nThis architecture means app servers are essentially \"deployment targets\" - they don't store apps themselves but receive and run them as instructed by Livebook Teams.","ref":"teams_concepts.html#the-app-server-lifecycle"},{"type":"extras","title":"The relationship between app servers and deployment groups - Livebook Teams concepts","doc":"A deployment group can have one or more app servers, allowing you to scale horizontally. An app server belongs to exactly one deployment group.\n\nUnderstanding deployment groups and app servers individually is important, but their real power comes from how they work together:\n\n1. **The deployment group defines the \"what\"**: What configuration, what security rules, what environment\n2. **The app server provides the \"where\"**: Where the apps actually run, where the compute happens\n3. **Livebook Teams orchestrates the \"how\"**: How apps get from your Livebook to the app server","ref":"teams_concepts.html#the-relationship-between-app-servers-and-deployment-groups"},{"type":"extras","title":"Docker","doc":"# Docker\n\nThere are two main use cases to deploy Livebook in the cloud. The first is to read and write notebooks in the cloud, instead of your machine. The second is to deploy notebooks as applications.","ref":"docker.html"},{"type":"extras","title":"Livebook in the cloud - Docker","doc":"You can deploy Livebook inside your infrastructure using Docker. The Dockerfile below provides a great starting point:\n\n```dockerfile\nFROM ghcr.io/livebook-dev/livebook\n\n# Configure your port accordingly\nENV LIVEBOOK_PORT=7860\nEXPOSE 7860\n\n# If you have a persistent volume, configure it here\nENV LIVEBOOK_DATA_PATH=\"/data\"\nUSER root\nRUN mkdir -p /data\nRUN chmod 777 /data\n```\n\nWe also recommend setting the `LIVEBOOK_PASSWORD` environment variable to a secret value. If it is not set, you will find the token to access Livebook in the logs. See all other supported [environment variables](../../README.md#environment-variables) to learn more.\n\nIf you want to run several Livebook instances behind a load balancer, you need to enable clustering. See the [Clustering](clustering.md) section.\n\nIf you plan to limit access to your Livebook via a proxy, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"docker.html#livebook-in-the-cloud"},{"type":"extras","title":"Docker compose - Docker","doc":"If using Docker Compose the following template is a good starting point:\n\n```yml\nservices:\n  livebook:\n    image: ghcr.io/livebook-dev/livebook\n    ports:\n      - 8090:8090\n      - 8091:8091\n    environment:\n      - LIVEBOOK_PORT=8090\n      - LIVEBOOK_IFRAME_PORT=8091\n```","ref":"docker.html#docker-compose"},{"type":"extras","title":"Kubernetes - Docker","doc":"If using k8s the following template is a good starting point. It includes a load balancer and preset clustering:\n\n```yml\napiVersion: v1\nkind: Service\nmetadata:\n  name: livebook-headless\nspec:\n  clusterIP: None\n  selector:\n    app: livebook\n\n---\n\napiVersion: v1\nkind: Service\nmetadata:\n  name: livebook-loadbalancer\nspec:\n  type: ClusterIP\n  ports:\n    - port: 8080\n      targetPort: 8080\n  selector:\n    app: livebook\n\n---\n\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: livebook\nspec:\n  # When deploying Livebook for authoring notebooks to Kubernetes,\n  # the number of replicas must be 1, since Livebook considers you\n  # will assign one instance per user.\n  replicas: 1\n  selector:\n    matchLabels:\n      app: livebook\n  template:\n    metadata:\n      labels:\n        app: livebook\n    spec:\n      containers:\n        - name: livebook\n          image: ghcr.io/livebook-dev/livebook:latest\n          ports:\n            - containerPort: 8080\n          env:\n            - name: POD_IP\n              valueFrom:\n                fieldRef:\n                  fieldPath: status.podIP\n            - name: POD_NAMESPACE\n              valueFrom:\n                fieldRef:\n                  fieldPath: metadata.namespace\n            - name: LIVEBOOK_NODE\n              value: \"livebook@$(POD_IP)\"\n            - name: LIVEBOOK_CLUSTER\n              value: \"dns:livebook-headless.$(POD_NAMESPACE).svc.cluster.local\"\n            - name: LIVEBOOK_PASSWORD\n              valueFrom:\n                secretKeyRef:\n                  name: livebook-secret\n                  key: LIVEBOOK_PASSWORD\n            - name: LIVEBOOK_SECRET_KEY_BASE\n              valueFrom:\n                secretKeyRef:\n                  name: livebook-secret\n                  key: LIVEBOOK_SECRET_KEY_BASE\n            - name: LIVEBOOK_COOKIE\n              valueFrom:\n                secretKeyRef:\n                  name: livebook-secret\n                  key: LIVEBOOK_COOKIE\n\n---\n\napiVersion: v1\nkind: Secret\nmetadata:\n  name: livebook-secret\n  namespace: livebook-namespace\ntype: Opaque\ndata:\n  LIVEBOOK_PASSWORD:  \n  LIVEBOOK_SECRET_KEY_BASE:  \n  LIVEBOOK_COOKIE:  \n```\n\nThe setup above does not set up a data directory, which means once you restart the instance, any configuration will be lost. If you have a persistent volume, you can point the `LIVEBOOK_DATA_PATH` environment variable to it.","ref":"docker.html#kubernetes"},{"type":"extras","title":"Deploy notebooks as applications - Docker","doc":"It is possible to deploy any notebook as an application in Livebook. Inside the notebook, open up the Application pane on the sidebar (with a rocket icon), click \"Manual Docker deployment\", and follow the required steps.\n\nIf you are using [Livebook Teams](https://livebook.dev/teams/), you can also deploy with the click of a button by running Livebook servers inside your infrastructure. To get started, open up Livebook and click \"Add Organization\" on the sidebar. Once completed, open up the Application pane on the sidebar (with a rocket icon), click \"Deploy with Livebook Teams\", and follow the deployment steps.\n\nThe deployment steps will show you to deploy your notebooks within Docker, Fly.io, and Kubernetes. This is effectively done by setting the `LIVEBOOK_TEAMS_AUTH`, which configures Livebook to run as a read-only instance connected to Livebook Teams.\n\nLivebook Teams also support airgapped deployments, pre-configured environment variables, shared team secrets, file storages, and more.","ref":"docker.html#deploy-notebooks-as-applications"},{"type":"extras","title":"Clustering","doc":"# Clustering\n\nIf you plan to run several Livebook instances behind a load balancer, you need to enable clustering via the `LIVEBOOK_CLUSTER` environment variable. This page describes how to configure the relevant environment variables. By default, Livebook uses port `13825` for nodes in a cluster to communicate.\n\nIf you are using [Livebook Teams](https://livebook.dev/teams/), you can deploy with the click of a button by running Livebook servers inside your infrastructure. To get started, open up Livebook and click \"Add Organization\" on the sidebar. Once completed, open up the Application pane on the sidebar (with a rocket icon), click \"Deploy with Livebook Teams\". We provide templates for clustering inside Fly.io and Kubernetes, without a need to follow the steps below.","ref":"clustering.html"},{"type":"extras","title":"Setting `LIVEBOOK_CLUSTER` - Clustering","doc":"You may set `LIVEBOOK_CLUSTER` to one of the following values.\n\n### `auto`\n\n> #### Attention {: .warning}\n>\n> \"auto\" is only a valid value if you're running Livebook's Docker image on AWS ECS (including Fargate), Kubernetes, and Fly.io.\n\nDetects the hosting platform and automatically sets up a cluster using DNS configuration. See platform specific notes below.\n\n#### AWS ECS & Fargate\n\nIf you're running Livebook in the **AWS ECS** environment, the `auto` configuration will automatically cluster based on the ECS Container Metadata HTTP API. The cluster's \"deployment\" name will be based on a SHA checksum of the ECS Container Image ID. Largely you don't need to care about this, but any Livebook deployment using the same image ID will be clustered together. If you want more containers (say in **AWS Fargate**), increase the `desiredCount` of the family.\n\nWhile ECS and Fargate won't need any further configuration for clustering, you will need to do network level configuration to allow the containers to talk to each other (using port 13825) and other resources (databases, S3, etc). That configuration is outside of the scope of this documentation. If you're having issues connecting, there's a good chance it's either you haven't setup the standard ports required, you haven't correctly configured the security groups, or you haven't correctly configured the HTTP listeners/load balancers.\n\n#### Fly.io\n\nWhen deploying Livebook to Fly.io, the `auto` configuration automatically connects your cluster using Fly's private networks over IPv6.\n\n#### Kubernetes\n\nWhen using the Livebook application, you can also choose \"auto\" for Kubernetes deployments, but those values are automatically replaced by a DNS query, such as `dns:livebook-headless.$(POD_NAMESPACE).svc.cluster.local`, when generating the relevant resource definitions. See [the Kubernetes section in the Docker guides](docker.md#Kubernetes) for an example.\n\n### `dns:QUERY`\n\nSets up a cluster using DNS for queries for A/AAAA records to discover new nodes. Additionally, you must additionally set the following env vars:\n\n- `LIVEBOOK_NODE=livebook_server@MACHINE_IP`, where `MACHINE_IP` is the machine IP of each deployed node\n\n- If your cloud requires IPv6, also set `ERL_AFLAGS=\"-proto_dist inet6_tcp\"`","ref":"clustering.html#setting-livebook_cluster"},{"type":"extras","title":"Setting other env vars - Clustering","doc":"In addition you must set `LIVEBOOK_SECRET_KEY_BASE` and `LIVEBOOK_COOKIE` to different random values (use `openssl rand -base64 48` to generate said values).\n\nYou may need to set additional environment variables at runtime. When using the Livebook Docker image, you can create a file at `/app/user/env.sh` that exports the necessary environment variables. This file is invoked right before booting Livebook.","ref":"clustering.html#setting-other-env-vars"},{"type":"extras","title":"FIPS mode","doc":"# FIPS mode\n\nFor environments that require security hardening, you might need to turn on FIPS ([Federal Information Processing Standards](https://en.wikipedia.org/wiki/Federal_Information_Processing_Standards)) mode. Turning FIPS is a complex procedure, this just enables you to do it.\n\nYou will need to have an Erlang installation that has been compiled with [FIPS enabled](https://www.erlang.org/doc/apps/crypto/fips).","ref":"fips.html"},{"type":"extras","title":"Docker example - FIPS mode","doc":"To do this in Docker, you will need to build it differently. Below is an example Dockerfile with FIPS-enabled Erlang/Elixir base image. You can use it as a base image for building Livebook. See the Livebook Dockerfile for further reference.\n\n```docker\nFROM registry.access.redhat.com/ubi8/ubi-minimal:8.9-1137\n# Set environment variables for path and language\nENV PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin\n\n# Install system dependencies and clean cache in one layer\nRUN microdnf install -y unzip autoconf git ncurses-devel openssl-devel gcc gcc-c++ make automake perl clang wget tar cmake glibc-locale-source glibc-langpack-en && \\\n    microdnf clean all && \\\n    rm -rf /var/cache/yum\n\nWORKDIR /install\n\n# Download, configure, and install Erlang/OTP with FIPS enabled\nARG ERLANG_VERSION\nRUN wget https://github.com/erlang/otp/archive/OTP-${ERLANG_VERSION}.tar.gz && \\\n    tar -xzvf OTP-${ERLANG_VERSION}.tar.gz && \\\n    cd otp-OTP-${ERLANG_VERSION} && \\\n    ./otp_build autoconf && \\\n    ./configure --enable-fips && \\\n    make && make install\n\n# Clone, checkout, and install Elixir\nARG ELIXIR_VERSION\nRUN git clone https://github.com/elixir-lang/elixir.git && \\\n    cd elixir && \\\n    git checkout v${ELIXIR_VERSION} && \\\n    make compile && \\\n    make install\n```","ref":"fips.html#docker-example"},{"type":"extras","title":"Nginx over HTTPS","doc":"# Nginx over HTTPS\n\nThis guide shows you how to use Nginx to serve Livebook over HTTPS.","ref":"nginx_https.html"},{"type":"extras","title":"Prerequisites - Nginx over HTTPS","doc":"- Nginx installed\n- Livebook installed\n- Both Livebook and Nginx running on the same machine or within the same network\n- SSL certificate and key files","ref":"nginx_https.html#prerequisites"},{"type":"extras","title":"Nginx configuration - Nginx over HTTPS","doc":"Use the following Nginx config file as a starting point:\n\n```nginx\nhttp {\n    server {\n        listen 443 ssl;\n        server_name your_domain;  # e.g., livebook.example.com\n\n        ssl_certificate /path/to/your/ssl_certificate.crt;  # e.g., /etc/nginx/ssl/livebook.crt\n        ssl_certificate_key /path/to/your/ssl_certificate.key;  # e.g., /etc/nginx/ssl/livebook.key\n\n        location / {\n            proxy_pass http://livebook_ip:livebook_port;  # e.g., http://172.20.0.3:8080 (Livebook's default port is 8080)\n            proxy_http_version 1.1;\n            proxy_set_header Upgrade $http_upgrade;\n            proxy_set_header Connection \"upgrade\";\n            proxy_set_header Host $host;\n            proxy_set_header X-Real-IP $remote_addr;\n            proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;\n            proxy_set_header X-Forwarded-Proto $scheme;\n        }\n    }\n\n    server {\n        listen 80;\n        server_name your_domain;  # e.g., livebook.example.com\n        return 301 https://$host$request_uri;\n    }\n}\n\nevents {}\n```","ref":"nginx_https.html#nginx-configuration"},{"type":"extras","title":"Basic Auth","doc":"# Basic Auth\n\nSetting up Basic Authentication is a simple mechanism for protecting all routes of your Livebook instance with a single username-password combo. However, because this password is shared across all users, this authentication mechanism cannot be used to identity users and more robust authentication methods provided by Livebook should be preferred. Basic Authentication occurs in addition to [Livebook's authentication](../authentication.md) for deployed notebooks and admins.","ref":"basic_auth.html"},{"type":"extras","title":"How to - Basic Auth","doc":"To integrate Basic Authentication with Livebook, set the `LIVEBOOK_IDENTITY_PROVIDER` environment variable to `basic_auth: : `, and then deploy or directly run your Livebook instance.","ref":"basic_auth.html#how-to"},{"type":"extras","title":"Livebook Teams - Basic Auth","doc":"[Livebook Teams](https://livebook.dev/teams/) users can deploy notebooks with the click of a button with built-in authentication via Livebook Teams. You can also pre-configure environment variables (such as `LIVEBOOK_IDENTITY_PROVIDER`), share team secrets, and file storages. Both online and airgapped deployment mechanisms are supported.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Workspace.app_info/0`](https://hexdocs.pm/kino/Kino.Workspace.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar. Then, inside the notebook of your choice, click \"Deploy with Livebook Teams\".","ref":"basic_auth.html#livebook-teams"},{"type":"extras","title":"Cloudflare","doc":"# Cloudflare\n\nSetting up Cloudflare authentication will protect all routes of your Livebook instance. It is particularly useful for adding authentication to Livebook instances with deployed notebooks. Cloudflare authentication occurs in addition to [Livebook's authentication](../authentication.md) for deployed notebooks and admins.\n\nOnce Cloudflare is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"cloudflare.html"},{"type":"extras","title":"How to - Cloudflare","doc":"To integrate your Cloudflare Zero Trust authentication with Livebook, set the\n`LIVEBOOK_IDENTITY_PROVIDER` environment variable to `cloudflare: `.\n\nFor more details about how to find your `team-name`, see:\nhttps://developers.cloudflare.com/cloudflare-one/glossary/#team-name.\n\nFor more information about Cloudflare Zero Trust, see:\nhttps://developers.cloudflare.com/cloudflare-one/.","ref":"cloudflare.html#how-to"},{"type":"extras","title":"Livebook Teams - Cloudflare","doc":"[Livebook Teams](https://livebook.dev/teams/) users can deploy notebooks with the click of a button with built-in authentication via Livebook Teams. You can also pre-configure environment variables (such as `LIVEBOOK_IDENTITY_PROVIDER`), share team secrets, and file storages. Both online and airgapped deployment mechanisms are supported.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Workspace.app_info/0`](https://hexdocs.pm/kino/Kino.Workspace.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar. Then, inside the notebook of your choice, click \"Deploy with Livebook Teams\".","ref":"cloudflare.html#livebook-teams"},{"type":"extras","title":"Google IAP","doc":"# Google IAP\n\nSetting up Google IAP authentication will protect all routes of your Livebook instance. It is particularly useful for adding authentication to Livebook instances with deployed notebooks. Google IAP authentication occurs in addition to [Livebook's authentication](../authentication.md) for deployed notebooks and admins.\n\nOnce Google IAP is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"google_iap.html"},{"type":"extras","title":"How to - Google IAP","doc":"To integrate your Google Identity-Aware Proxy (IAP) authentication with Livebook,\nset the `LIVEBOOK_IDENTITY_PROVIDER` environment variable to `google_iap: `.\n\nFor more information about Google IAP, see https://cloud.google.com/iap/docs/concepts-overview.\n\nOnly access with Google accounts is supported. See https://cloud.google.com/iap/docs/authenticate-users-google-accounts.\n\nFor more details about how to find your JWT audience, see https://cloud.google.com/iap/docs/signed-headers-howto and look for \"Signed Header JWT Audience.\"","ref":"google_iap.html#how-to"},{"type":"extras","title":"Livebook Teams - Google IAP","doc":"[Livebook Teams](https://livebook.dev/teams/) users can deploy notebooks with the click of a button with built-in authentication via Livebook Teams. You can also pre-configure environment variables (such as `LIVEBOOK_IDENTITY_PROVIDER`), share team secrets, and file storages. Both online and airgapped deployment mechanisms are supported.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Workspace.app_info/0`](https://hexdocs.pm/kino/Kino.Workspace.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar. Then, inside the notebook of your choice, click \"Deploy with Livebook Teams\".","ref":"google_iap.html#livebook-teams"},{"type":"extras","title":"Tailscale","doc":"# Tailscale\n\nSetting up Tailscale authentication will protect all routes of your Livebook instance. It is particularly useful for adding authentication to Livebook instances with deployed notebooks. Tailscale authentication occurs in addition to [Livebook's authentication](../authentication.md) for deployed notebooks and admins.\n\nOnce Tailscale is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"tailscale.html"},{"type":"extras","title":"How to - Tailscale","doc":"To integrate Tailscale authentication with Livebook,\nset the `LIVEBOOK_IDENTITY_PROVIDER` environment variable to `tailscale:tailscale-socket-path`, make sure the `tailscale` CLI is installed and available on your machine (or your Docker image).\n\nIf you want to access Livebook on the same machine as you are hosting it,\nyou must also set the `LIVEBOOK_IP` variable to your Tailscale IP.\n\nTo do both of these things, run:\n\n```bash\nLIVEBOOK_IP=$(tailscale ip -1 | tr -d '\\n') \\\nLIVEBOOK_IDENTITY_PROVIDER=tailscale:/var/run/tailscale/tailscaled.sock \\\nlivebook server\n```\n\nSee https://tailscale.com/blog/tailscale-auth-nginx/ for more information\non how Tailscale authentication works.","ref":"tailscale.html#how-to"},{"type":"extras","title":"macOS - Tailscale","doc":"On macOS, Tailscale uses a password-protected TCP port instead of a unix socket. The following script automatically detects the port and password, then starts Livebook with the correct Tailscale configuration:\n\n```bash\n#!/bin/bash\n# This script is adapted from https://github.com/tailscale/tailscale/blob/v1.80.2/safesocket/safesocket_darwin.go#L69-L160\n\n# When Tailscale was installed via Mac App Store\nport_and_token=$(lsof -n -a -c IPNExtension -F | grep -o \"sameuserproof-[0-9]*-[a-f0-9]*\" | head -1)\nif [ ! -z \"$port_and_token\" ]; then\n    port=$(echo \"$port_and_token\" | cut -d'-' -f2)\n    token=$(echo \"$port_and_token\" | cut -d'-' -f3)\nelse\n    # When Tailscale was installed using the standalone variant\n    port=$(readlink /Library/Tailscale/ipnport)\n    if [ ! -z \"$port\" ]; then\n        token=$(cat \"/Library/Tailscale/sameuserproof-$port\")\n    fi\nfi\n\ntailscale_ip=$(exec $(ps -xo comm | grep MacOS/Tailscale$) ip | head -1 | tr -d '\\n')\n\nif [ ! -z \"$port\" ] && [ ! -z \"$token\" ] && [ ! -z \"$tailscale_ip\" ]; then\n    LIVEBOOK_IP=$tailscale_ip \\\n    LIVEBOOK_IDENTITY_PROVIDER=tailscale:http://:$token@127.0.0.1:$port \\\n    livebook server\nelse\n    echo \"Error: Missing required configuration\"\n    [ -z \"$port\" ] && echo \"- Could not determine port\"\n    [ -z \"$token\" ] && echo \"- Could not determine token\"\n    [ -z \"$tailscale_ip\" ] && echo \"- Could not determine Tailscale IP\"\nfi\n```","ref":"tailscale.html#macos"},{"type":"extras","title":"Livebook Teams - Tailscale","doc":"[Livebook Teams](https://livebook.dev/teams/) users can deploy notebooks with the click of a button with built-in authentication via Livebook Teams. You can also pre-configure environment variables (such as `LIVEBOOK_IDENTITY_PROVIDER`), share team secrets, and file storages. Both online and airgapped deployment mechanisms are supported.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Workspace.app_info/0`](https://hexdocs.pm/kino/Kino.Workspace.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar. Then, inside the notebook of your choice, click \"Deploy with Livebook Teams\".","ref":"tailscale.html#livebook-teams"},{"type":"extras","title":"Custom","doc":"# Custom\n\nIt is possible to provide custom Zero Trust Authentication (ZTA) inside Livebook's Docker images.\n\nTo do so, you must define a file with the `.exs` extension inside the `/app/user/extensions` of your Livebook image, for example, `/app/user/extensions/my_auth.exs`. This file should define at least one module, which implements the ZTA skeleton below:\n\n```elixir\ndefmodule MyAuth do\n  use GenServer\n\n  @spec start_link(keyword) :: {:ok, pid()}\n  def start_link(opts) do\n    identity_key = opts[:identity_key]\n    GenServer.start_link(__MODULE__, identity_key, Keyword.take(opts, [:name]))\n  end\n\n  @spec authenticate(GenServer.server(), Plug.Conn.t(), keyword()) ::\n          {Plug.Conn.t(), map() | nil}\n  def authenticate(server, conn, opts \\\\ []) do\n    # Connects to the GenServer given by `server` and returns the user information.\n    # See `opts[:fields]` for the fields to be returned in the map.\n    # Return nil if the user cannot be authenticated.\n  end\nend\n```\n\nThen you must configure Livebook to use the module above as your identity provider:\n\n```bash\nLIVEBOOK_IDENTITY_PROVIDER=\"custom:MyAuth\"\n```\n\nOr, if you want to pass a custom identity key:\n\n```bash\nLIVEBOOK_IDENTITY_PROVIDER=\"custom:MyAuth:my-key\"\n```\n\nKeep in mind that the identity provider contract in Livebook is still evolving and it may change in future releases. Additionally, your code may rely on two dependencies: [Req ~> 0.4](https://hexdocs.pm/req) and [JOSE ~> 1.11](https://hexdocs.pm/jose).","ref":"custom_auth.html"},{"type":"extras","title":"Development - Custom","doc":"If you want to try your custom identity provider in development, you can [clone Livebook's git repository](https://github.com/livebook-dev/livebook) and then execute the following command inside Livebook's root folder:\n\n```elixir\n$ mix setup\n$ LIVEBOOK_IDENTITY_PROVIDER=\"custom:MyAuth\" elixir -r path/to/my_auth.exs -S mix phx.server\n```","ref":"custom_auth.html#development"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}